@@ -166,8 +166,7 @@ KoFilter::ConversionStatus PptxXmlDocumentReader::readInternal()
     return KoFilter::OK;
 }
 
-PptxSlideProperties* PptxXmlDocumentReader::slideLayoutProperties(
-    const QString& slidePath, const QString& slideFile)
+PptxSlideProperties* PptxXmlDocumentReader::slideLayoutProperties(const QString& slidePath, const QString& slideFile)
 {
     const QString slideLayoutPathAndFile(m_context->relationships->targetForType(
         slidePath, slideFile,
@@ -258,14 +257,17 @@ PptxSlideProperties* PptxXmlDocumentReader::slideLayoutProperties(
 
 #undef CURRENT_EL
 #define CURRENT_EL sldId
-//! p:sldId handler (Slide ID)  ECMA-376, 19.2.1.33, p. 2797.
-/*! This element specifies a presentation slide that is available within the
- *  corresponding presentation.
+//! p:sldId handler (Slide ID)
+/*! ECMA-376, 19.2.1.33, p. 2797.
 
- Parent elements:
-    - [done] sldIdLst (§19.2.1.34)
- Child elements:
-    - extLst (Extension List)
+  This element specifies a presentation slide that is available within the
+  corresponding presentation.
+
+  Parent elements:
+  - [done] sldIdLst (§19.2.1.34)
+
+  Child elements:
+  - extLst (Extension List)
 */
 KoFilter::ConversionStatus PptxXmlDocumentReader::read_sldId()
 {
@@ -356,8 +358,7 @@ KoFilter::ConversionStatus PptxXmlDocumentReader::read_sldId()
 
     // 2nd reading round
     context.firstReadingRound = false;
-    status = m_context->import->loadAndParseDocument(
-        &slideReader, slidePath + '/' + slideFile, &context);
+    status = m_context->import->loadAndParseDocument(&slideReader, slidePath + '/' + slideFile, &context);
     if (status != KoFilter::OK) {
         kDebug() << slideReader.errorString();
         return status;
