@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
 */
 #include <q3header.h>
-#include <qlayout.h>
+#include <QLayout>
 //Added by qt3to4:
 #include <Q3VBoxLayout>
 #include <Q3HBoxLayout>
