@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003-2007 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2012 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -76,7 +76,7 @@ public:
             , internalFields(0)
             , fieldsExpandedWithInternalAndRowID(0)
             , fieldsExpandedWithInternal(0)
-            //, orderByColumnList(copy->orderByColumnList)
+            , orderByColumnList(0)
             , autoincFields(0)
             , columnsOrder(0)
             , columnsOrderWithoutAsterisks(0)
@@ -97,35 +97,35 @@ public:
         if (copy) {
             // deep copy
             *this = *copy;
-            if (copy->fieldsExpanded)
-                fieldsExpanded = new QueryColumnInfo::Vector(*copy->fieldsExpanded);
-            if (copy->internalFields)
-                internalFields = new QueryColumnInfo::Vector(*copy->internalFields);
-            if (copy->fieldsExpandedWithInternalAndRowID)
-                fieldsExpandedWithInternalAndRowID = new QueryColumnInfo::Vector(
-                    *copy->fieldsExpandedWithInternalAndRowID);
-            if (copy->fieldsExpandedWithInternal)
-                fieldsExpandedWithInternal = new QueryColumnInfo::Vector(
-                    *copy->fieldsExpandedWithInternal);
-            if (copy->autoincFields)
-                autoincFields = new QueryColumnInfo::List(*copy->autoincFields);
-            if (copy->columnsOrder)
-                columnsOrder = new QHash<QueryColumnInfo*, int>(*copy->columnsOrder);
-            if (copy->columnsOrderWithoutAsterisks)
-                columnsOrderWithoutAsterisks = new QHash<QueryColumnInfo*, int>(
-                    *copy->columnsOrderWithoutAsterisks);
-            if (copy->columnsOrderExpanded)
-                columnsOrderExpanded = new QHash<QueryColumnInfo*, int>(*copy->columnsOrderExpanded);
-            if (copy->pkeyFieldsOrder)
-                pkeyFieldsOrder = new QVector<int>(*copy->pkeyFieldsOrder);
-            if (copy->whereExpr)
+            // <clear, so computeFieldsExpanded() will re-create it>
+            fieldsExpanded = 0;
+            internalFields = 0;
+            columnsOrder = 0;
+            columnsOrderWithoutAsterisks = 0;
+            columnsOrderExpanded = 0;
+            autoincFields = 0;
+            autoIncrementSQLFieldsList.clear();
+            columnInfosByNameExpanded.clear();
+            columnInfosByName.clear();
+            ownedVisibleColumns = 0;
+            fieldsExpandedWithInternalAndRowID = 0;
+            fieldsExpandedWithInternal = 0;
+            pkeyFieldsOrder = 0;
+            fakeRowIDCol = 0;
+            fakeRowIDField = 0;
+            ownedVisibleColumns = 0;
+            // </clear, so computeFieldsExpanded() will re-create it>
+            if (copy->whereExpr) {
                 whereExpr = copy->whereExpr->copy();
-            if (copy->fakeRowIDCol)
-                fakeRowIDCol = new QueryColumnInfo(*copy->fakeRowIDCol);
-            if (copy->fakeRowIDField)
-                fakeRowIDField = new Field(*copy->fakeRowIDField);
-            if (copy->ownedVisibleColumns)
-                ownedVisibleColumns = new Field::List(*copy->ownedVisibleColumns);
+            }
+            // "*this = *copy" causes copying pointers; pull of them without destroying,
+            // will be deep-copied in the QuerySchema ctor.
+            asterisks.setAutoDelete(false);
+            asterisks.clear();
+            asterisks.setAutoDelete(true);
+        }
+        else {
+            orderByColumnList = new OrderByColumnList;
         }
     }
     ~QuerySchemaPrivate() {
@@ -138,6 +138,7 @@ public:
         }
         delete fieldsExpandedWithInternalAndRowID;
         delete fieldsExpandedWithInternal;
+        delete orderByColumnList;
         delete autoincFields;
         delete columnsOrder;
         delete columnsOrderWithoutAsterisks;
@@ -166,7 +167,9 @@ public:
     }
 
     void clearCachedData() {
-        orderByColumnList.clear();
+        if (orderByColumnList) {
+            orderByColumnList->clear();
+        }
         if (fieldsExpanded) {
             qDeleteAll(*fieldsExpanded);
             delete fieldsExpanded;
@@ -316,7 +319,7 @@ public:
     QueryColumnInfo::Vector *fieldsExpandedWithInternal;
 
     /*! A list of fields for ORDER BY section. @see QuerySchema::orderByColumnList(). */
-    OrderByColumnList orderByColumnList;
+    OrderByColumnList* orderByColumnList;
 
     /*! A cache for autoIncrementFields(). */
     QueryColumnInfo::List *autoincFields;
@@ -409,6 +412,33 @@ OrderByColumn::OrderByColumn(Field& field, bool ascending)
 {
 }
 
+OrderByColumn* OrderByColumn::copy(QuerySchema* fromQuery, QuerySchema* toQuery) const
+{
+    if (m_field) {
+        return new OrderByColumn(*m_field, m_ascending);
+    }
+    if (m_column) {
+        QueryColumnInfo* columnInfo;
+        if (fromQuery && toQuery) {
+            int columnIndex = fromQuery->columnsOrder().value(m_column);
+            if (columnIndex < 0) {
+                kDebug() << "index not found for column" << m_column->debugString();
+                return 0;
+            }
+            columnInfo = toQuery->expandedOrInternalField(columnIndex);
+            if (!columnInfo) {
+                kDebug() << "column info not found at index" << columnIndex << "in toQuery";
+                return 0;
+            }
+        }
+        else {
+            columnInfo = m_column;
+        }
+        return new OrderByColumn(*columnInfo, m_ascending, m_pos);
+    }
+    return 0;
+}
+
 OrderByColumn::~OrderByColumn()
 {
 }
@@ -427,36 +457,35 @@ QString OrderByColumn::debugString() const
            : QString("NONE");
 }
 
-QString OrderByColumn::toSQLString(bool includeTableName, Driver *drv, int identifierEscaping) const
+QString OrderByColumn::toSQLString(bool includeTableName, const Driver *drv, int identifierEscaping) const
 {
     const QString orderString(m_ascending ? "" : " DESC");
-    QString fieldName, tableName;
+    QString fieldName, tableName, collationString;
     if (m_column) {
         if (m_pos > -1)
             return QString::number(m_pos + 1) + orderString;
         else {
             if (includeTableName && m_column->alias.isEmpty()) {
-                tableName = m_column->field->table()->name();
-                if (drv)
-                    tableName = drv->escapeIdentifier(tableName, identifierEscaping);
-                tableName += ".";
+                tableName = KexiDB::escapeIdentifier(
+                                drv, m_column->field->table()->name(), identifierEscaping) + '.';
             }
-            fieldName = m_column->aliasOrName();
-            if (drv)
-                fieldName = drv->escapeIdentifier(fieldName, identifierEscaping);
+            fieldName = KexiDB::escapeIdentifier(drv, m_column->aliasOrName(), identifierEscaping);
+        }
+        if (m_column->field->isTextType() && drv) {
+            collationString = drv->collationSQL();
         }
     } else {
-        if (includeTableName) {
-            tableName = m_field->table()->name();
-            if (drv)
-                tableName = drv->escapeIdentifier(tableName, identifierEscaping);
-            tableName += ".";
+        if (m_field && includeTableName) {
+            tableName = KexiDB::escapeIdentifier(
+                            drv, m_field->table()->name(), identifierEscaping) + '.';
+        }
+        fieldName = KexiDB::escapeIdentifier(drv, m_field ? m_field->name() : "??"/*error*/,
+                                             identifierEscaping);
+        if (m_field && m_field->isTextType() && drv) {
+            collationString = drv->collationSQL();
         }
-        fieldName = m_field ? m_field->name() : "??"/*error*/;
-        if (drv)
-            fieldName = drv->escapeIdentifier(fieldName, identifierEscaping);
     }
-    return tableName + fieldName + orderString;
+    return tableName + fieldName + orderString + collationString;
 }
 
 //=======================================
@@ -466,11 +495,15 @@ OrderByColumnList::OrderByColumnList()
 {
 }
 
-OrderByColumnList::OrderByColumnList(const OrderByColumnList& other)
+OrderByColumnList::OrderByColumnList(const OrderByColumnList& other,
+                                     QuerySchema* fromQuery, QuerySchema* toQuery)
         : OrderByColumnListBase()
 {
     for (QList<OrderByColumn*>::ConstIterator it(other.constBegin()); it != other.constEnd(); ++it) {
-        appendColumn(**it);
+        OrderByColumn* order = (*it)->copy(fromQuery, toQuery);
+        if (order) {
+            append(order);
+        }
     }
 }
 
@@ -546,11 +579,6 @@ bool OrderByColumnList::appendField(QuerySchema& querySchema,
     return false;
 }
 
-void OrderByColumnList::appendColumn(const OrderByColumn& column)
-{
-    append(new OrderByColumn(column));
-}
-
 QString OrderByColumnList::debugString() const
 {
     if (isEmpty())
@@ -564,7 +592,7 @@ QString OrderByColumnList::debugString() const
     return dbg;
 }
 
-QString OrderByColumnList::toSQLString(bool includeTableNames, Driver *drv, int identifierEscaping) const
+QString OrderByColumnList::toSQLString(bool includeTableNames, const Driver *drv, int identifierEscaping) const
 {
     QString string;
     for (QList<OrderByColumn*>::ConstIterator it(constBegin()); it != constEnd(); ++it) {
@@ -629,12 +657,18 @@ QuerySchema::QuerySchema(const QuerySchema& querySchema)
         Field *copiedField;
         if (dynamic_cast<QueryAsterisk*>(f)) {
             copiedField = f->copy();
-            if (static_cast<const KexiDB::FieldList *>(f->m_parent) == &querySchema)
+            if (static_cast<const KexiDB::FieldList *>(f->m_parent) == &querySchema) {
                 copiedField->m_parent = this;
-        } else
+            }
+        }
+        else {
             copiedField = f;
+        }
         addField(copiedField);
     }
+    // this deep copy must be after the 'd' initialization because fieldsExpanded() is used there
+    d->orderByColumnList = new OrderByColumnList(*querySchema.d->orderByColumnList,
+                                                 const_cast<QuerySchema*>(&querySchema), this);
 }
 
 QuerySchema::~QuerySchema()
@@ -690,6 +724,8 @@ FieldList& QuerySchema::insertField(uint position, Field *field,
     d->clearCachedData();
     FieldList::insertField(position, field);
     if (field->isQueryAsterisk()) {
+        //kDebug() << "d->asterisks.append:" << field;
+        //field->debug();
         d->asterisks.append(field);
         //if this is single-table asterisk,
         //add a table to list if doesn't exist there:
@@ -765,6 +801,8 @@ void QuerySchema::removeField(KexiDB::Field *field)
         return;
     d->clearCachedData();
     if (field->isQueryAsterisk()) {
+        //kDebug() << "d->asterisks.removeAt:" << field;
+        //field->debug();
         d->asterisks.removeAt(d->asterisks.indexOf(field));   //this will destroy this asterisk
     }
 //TODO: should we also remove table for this field or asterisk?
@@ -1651,7 +1689,7 @@ QueryColumnInfo::List* QuerySchema::autoIncrementFields()
     return d->autoincFields;
 }
 
-QString QuerySchema::sqlColumnsList(QueryColumnInfo::List* infolist, Driver *driver)
+QString QuerySchema::sqlColumnsList(QueryColumnInfo::List* infolist, const Driver *driver)
 {
     if (!infolist)
         return QString();
@@ -1663,17 +1701,17 @@ QString QuerySchema::sqlColumnsList(QueryColumnInfo::List* infolist, Driver *dri
             result += ",";
         else
             start = false;
-        result += driver->escapeIdentifier(ci->field->name());
+        result += KexiDB::escapeIdentifier(driver, ci->field->name());
     }
     return result;
 }
 
-QString QuerySchema::autoIncrementSQLFieldsList(Driver *driver)
+QString QuerySchema::autoIncrementSQLFieldsList(const Driver *driver)
 {
-    if ((Driver *)d->lastUsedDriverForAutoIncrementSQLFieldsList != driver
+    if ((const Driver *)d->lastUsedDriverForAutoIncrementSQLFieldsList != driver
             || d->autoIncrementSQLFieldsList.isEmpty()) {
         d->autoIncrementSQLFieldsList = QuerySchema::sqlColumnsList(autoIncrementFields(), driver);
-        d->lastUsedDriverForAutoIncrementSQLFieldsList = driver;
+        d->lastUsedDriverForAutoIncrementSQLFieldsList = const_cast<Driver*>(driver);
     }
     return d->autoIncrementSQLFieldsList;
 }
@@ -1739,16 +1777,14 @@ BaseExpr *QuerySchema::whereExpression() const
 
 void QuerySchema::setOrderByColumnList(const OrderByColumnList& list)
 {
-    d->orderByColumnList.clear();
-    for (QList<OrderByColumn*>::ConstIterator it(list.constBegin()); it != list.constEnd(); ++it) {
-        d->orderByColumnList.appendColumn(**it);
-    }
+    delete d->orderByColumnList;
+    d->orderByColumnList = new OrderByColumnList(list, 0, 0);
 // all field names should be found, exit otherwise ..........?
 }
 
 OrderByColumnList& QuerySchema::orderByColumnList() const
 {
-    return d->orderByColumnList;
+    return *d->orderByColumnList;
 }
 
 QuerySchemaParameterList QuerySchema::parameters()
@@ -1826,8 +1862,15 @@ QueryAsterisk::QueryAsterisk(QuerySchema *query, TableSchema *table)
     setType(Field::Asterisk);
 }
 
+QueryAsterisk::QueryAsterisk(const QueryAsterisk& asterisk)
+        : Field(asterisk)
+        , m_table(asterisk.table())
+{
+}
+
 QueryAsterisk::~QueryAsterisk()
 {
+    //kDebug() << this << debugString();
 }
 
 Field* QueryAsterisk::copy() const
