@@ -48,6 +48,7 @@ class Part;
 class KXMLGUIClient;
 class KXMLGUIFactory;
 class KexiMainWidget;
+class KexiUserFeedbackAgent;
 
 #include <KTabWidget>
 
@@ -60,6 +61,7 @@ public:
     virtual ~KexiMainWindowTabWidget();
 public slots:
     void closeTab();
+
 protected:
     //! Implemented to add context menu
     void contextMenu(int index, const QPoint& point);
@@ -72,6 +74,11 @@ protected:
 
     KexiMainWidget *m_mainWidget;
     KAction *m_closeAction;
+
+private:
+    int m_tabIndex;
+
+    void setTabIndexFromContextMenu(const int clickedIndex);
 };
 
 #define KexiMainWindowSuper QWidget //KMainWindow
@@ -214,6 +221,18 @@ public:
     // see KexiMainWindowIface
     virtual KToolBar *toolBar(const QString& name) const;
 
+    //! Shows design tab when switching between objects or views.
+    void showDesignTabIfNeeded(const QString &partClass, const Kexi::ViewMode viewMode);
+
+    //! Sets currently visible tab when switching to design view, according to object type opened.
+    virtual void setDesignTabIfNeeded(const QString &partClass);
+
+    //! Hides tabs when they are closed (depending on class)
+    virtual void closeTab(const QString &partClass);
+
+    /*! Implemented for KexiMainWindow */
+    virtual KexiUserFeedbackAgent* userFeedbackAgent() const;
+
 public slots:
     /*! Implemented for KexiMainWindow */
     virtual tristate closeWindow(KexiWindow *window);
@@ -339,6 +358,9 @@ public slots:
      One example is Project Navigator. @see KexiMainWindowIface */
     virtual void addSearchableModel(KexiSearchableModel *model);
 
+    //! Shows Context sensitive ToolTab when changing current Object Tab
+    void showTabIfNeeded();
+
 signals:
     //! Emitted to make sure the project can be close.
     //! Connect a slot here and set \a cancel to true to cancel the closing.
