@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2011 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2012 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -38,8 +38,9 @@
 #include <QPainter>
 #include <QDesktopWidget>
 #include <QKeyEvent>
- 
+#include <KTabWidget>
 #include "KexiSearchLineEdit.h"
+#include "KexiUserFeedbackAgent.h"
 #include <kexiutils/SmallToolButton.h>
 class KexiProjectNavigator;
 
@@ -74,6 +75,19 @@ public:
     KHelpMenu *helpMenu() const;
 
     void addSearchableModel(KexiSearchableModel *model);
+    
+    KToolBar *createToolBar(const char *name, const QString& caption);
+    
+    void setCurrentTab(const QString& name);
+
+    //! Sets current tab to @a index, counting from first visible (non-Kexi) tab.
+    //! In non-user mode, the first visible tab is "create" tab.
+    void setCurrentTab(int index);
+
+    void hideTab(const QString& name);
+    
+    void showTab(const QString& name);
+    
 
 public slots:
     void setMainMenuContent(QWidget *w);
@@ -140,12 +154,22 @@ public:
      : QWidget(parent)
     {
         setAutoFillBackground(true);
+        alterBackground();
+    }
+    void alterBackground()
+    {
         QPalette pal(palette());
-        QColor bg(Qt::white);
+        QColor bg(KexiUtils::isLightColorScheme() ? Qt::white : Qt::black);
         bg.setAlpha(150);
         pal.setColor(QPalette::Window, bg);
         setPalette(pal);
     }
+    virtual void changeEvent(QEvent *e) {
+        if (e->type() == QEvent::PaletteChange) {
+            alterBackground();
+        }
+        QWidget::changeEvent(e);
+    }
 };
 
 class TopLineKexiMainMenuWidget : public QWidget
@@ -431,10 +455,12 @@ public:
         tabBarAnimation.setPropertyName("opacity");
         tabBarAnimation.setDuration(500);
         connect(&tabBarAnimation, SIGNAL(finished()), q, SLOT(tabBarAnimationFinished()));
+        tabIndex = 0;
+        lowestIndex = 2;
     }
 
     KToolBar *createToolBar(const char *name, const QString& caption);
-
+    int tabIndex;
 
 public slots:
     void showMainMenu(const char* actionName = 0);
@@ -459,6 +485,9 @@ public:
 #endif
     //! Toolbars for name
     QHash<QString, KToolBar*> toolbarsForName;
+    QHash<QString, int> toolbarsIndexForName;
+    QHash<QString, QString> toolbarsCaptionForName;
+    QVector<bool> toolbarsVisibleForIndex;
     QHash<QWidget*, QAction*> extraActions;
     bool rolledUp;
     QPropertyAnimation tabBarAnimation;
@@ -466,6 +495,13 @@ public:
     int rolledUpIndex;
     KHelpMenu *helpMenu;
     KexiSearchLineEdit *searchLineEdit;
+    void setCurrentTab(const QString& name);
+    void hideTab(const QString& name);
+    void showTab(const QString& name);
+#ifndef NDEBUG
+    void debugToolbars() const;
+#endif
+    int lowestIndex;
 };
 
 #include <kexiutils/styleproxy.h>
@@ -487,6 +523,8 @@ public:
     virtual QSize tabSizeHint(int index) const;
 
     KexiTabbedToolBarStyle* customStyle;
+protected:
+    virtual void changeEvent(QEvent *e);
 };
 
 //! Style proxy for KexiTabbedToolBar, to get the "Kexi" tab style right.
@@ -494,12 +532,18 @@ class KexiTabbedToolBarStyle : public KexiUtils::StyleProxy
 {
 public:
     explicit KexiTabbedToolBarStyle(QStyle *style) : KexiUtils::StyleProxy(style) {
-        const QString kexiBlackFname
-            = KStandardDirs::locate("data", "kexi/pics/kexi-logo.png");
-        kexiBlackPixmap = QPixmap(kexiBlackFname);
+        updateLogo();
     }
     virtual ~KexiTabbedToolBarStyle() {
     }
+    void updateLogo() {
+        const QString kexiBlackFname
+            = KStandardDirs::locate("data",
+                                    KexiUtils::isLightColorScheme()
+                                    ? "kexi/pics/kexi-logo.png"
+                                    : "kexi/pics/kexi-logo-white.png");
+        kexiBlackPixmap = QPixmap(kexiBlackFname);
+    }
     virtual void drawControl(ControlElement element, const QStyleOption *option,
                              QPainter *painter, const QWidget *widget = 0) const
     {
@@ -663,6 +707,14 @@ QSize KexiTabbedToolBarTabBar::tabSizeHint(int index) const
     return KTabBar::tabSizeHint(index);
 }
 
+void KexiTabbedToolBarTabBar::changeEvent(QEvent *e)
+{
+    if (e->type() == QEvent::PaletteChange) {
+        customStyle->updateLogo();
+    }
+    KTabBar::changeEvent(e);
+}
+
 void KexiTabbedToolBar::Private::toggleMainMenu()
 {
     if (q->mainMenuVisible())
@@ -761,7 +813,10 @@ KToolBar *KexiTabbedToolBar::Private::createToolBar(const char *name, const QStr
     toolbarsForName.insert(name, tbar);
     tbar->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
     tbar->setObjectName(name);
-    q->addTab(tbar, caption);
+    toolbarsCaptionForName.insert(name, caption);
+    tabIndex = q->addTab(tbar, caption);
+    toolbarsVisibleForIndex.append(true);
+    toolbarsIndexForName.insert(name, tabIndex);
     return tbar;
 }
 
@@ -861,7 +916,9 @@ KexiTabbedToolBar::KexiTabbedToolBar(QWidget *parent)
     QWidget *dummyWidgetForMainMenu = new QWidget(this);
     dummyWidgetForMainMenu->setObjectName("kexi");
     addTab(dummyWidgetForMainMenu, i18nc("File menu", "&File"));
+    d->toolbarsVisibleForIndex.append(true);
     addTab(new QWidget(this), QString()); // dummy for spacer
+    d->toolbarsVisibleForIndex.append(true);
 
     if (!userMode) {
         d->createWidgetToolBar = d->createToolBar("create", i18n("Create"));
@@ -947,6 +1004,67 @@ KexiTabbedToolBar::KexiTabbedToolBar(QWidget *parent)
     setFocusPolicy(Qt::NoFocus);
 }
 
+void KexiTabbedToolBar::Private::setCurrentTab(const QString& name)
+{
+    q->setCurrentWidget(q->toolBar(name));
+}
+
+void KexiTabbedToolBar::Private::hideTab(const QString& name)
+{
+    q->removeTab(q->indexOf(toolbarsForName.value(name)));
+    toolbarsVisibleForIndex[toolbarsIndexForName.value(name)] = false;
+}
+
+#ifndef NDEBUG
+void KexiTabbedToolBar::Private::debugToolbars() const
+{
+    kDebug() << "QHash<QString, KToolBar*> toolbarsForName:";
+    for (QHash<QString, KToolBar*>::ConstIterator it(toolbarsForName.constBegin());
+         it!=toolbarsForName.constEnd(); ++it)
+    {
+        kDebug() << it.key() << "->" << it.value();
+    }
+    kDebug() << "QHash<QString, int> toolbarsIndexForName:";
+    for (QHash<QString, int>::ConstIterator it(toolbarsIndexForName.constBegin());
+         it!=toolbarsIndexForName.constEnd(); ++it)
+    {
+        kDebug() << it.key() << "->" << it.value();
+    }
+    kDebug() << "QHash<QString, QString> toolbarsCaptionForName:";
+    for (QHash<QString, QString>::ConstIterator it(toolbarsCaptionForName.constBegin());
+         it!=toolbarsCaptionForName.constEnd(); ++it)
+    {
+        kDebug() << it.key() << "->" << it.value();
+    }
+    kDebug() << "QVector<bool> toolbarsVisibleForIndex:";
+    for (int i = 0; i < toolbarsVisibleForIndex.size(); i++) {
+        kDebug() << i << "->" << toolbarsVisibleForIndex[i];
+    }
+}
+#endif
+
+void KexiTabbedToolBar::Private::showTab(const QString& name)
+{
+    kDebug() << "name:" << name;
+    kDebug() << "toolbarsForName.value(name):" << toolbarsForName.value(name);
+    kDebug() << "toolbarsIndexForName.value(name):" << toolbarsIndexForName.value(name);
+    kDebug() << "q->indexOf(toolbarsForName.value(name))" << q->indexOf(toolbarsForName.value(name));
+#ifndef NDEBUG
+    //debugToolbars();
+#endif
+    if (q->indexOf(toolbarsForName.value(name)) == -1) {
+        int h = 0;
+        // count h = invisible tabs before this
+        for (int i = lowestIndex; i < toolbarsIndexForName.value(name); i++) {
+            if (!toolbarsVisibleForIndex.at(i))
+                h++;
+        }
+        q->insertTab(toolbarsIndexForName.value(name) - h,
+                     toolbarsForName.value(name), toolbarsCaptionForName.value(name));
+        toolbarsVisibleForIndex[toolbarsIndexForName.value(name)] = true;
+    }
+}
+
 KexiTabbedToolBar::~KexiTabbedToolBar()
 {
     delete d;
@@ -1266,6 +1384,32 @@ void KexiTabbedToolBar::addSearchableModel(KexiSearchableModel *model)
     d->searchLineEdit->addSearchableModel(model);
 }
 
+KToolBar* KexiTabbedToolBar::createToolBar(const char* name, const QString& caption)
+{
+    return d->createToolBar(name, caption);
+}
+
+void KexiTabbedToolBar::setCurrentTab(const QString& name)
+{
+    d->setCurrentTab(name);
+}
+
+void KexiTabbedToolBar::setCurrentTab(int index)
+{
+    setCurrentIndex(d->lowestIndex + index);
+}
+
+void KexiTabbedToolBar::hideTab(const QString& name)
+{
+    d->hideTab(name);
+}
+
+void KexiTabbedToolBar::showTab(const QString& name)
+{
+    d->showTab(name);
+}
+
+
 //! @short A widget being main part of KexiMainWindow
 class KexiMainWidget : public KMainWindow
 {
@@ -1286,6 +1430,8 @@ protected:
     virtual bool queryExit();
 protected slots:
     void slotCurrentTabIndexChanged(int index);
+signals:
+    void currentTabIndexChanged(int index);
 
 private:
     void setupCentralWidget();
@@ -1340,6 +1486,7 @@ void KexiMainWidget::slotCurrentTabIndexChanged(int index)
     if (m_mainWindow)
         m_mainWindow->activeWindowChanged(cont->window, (KexiWindow*)m_previouslyActiveWindow);
     m_previouslyActiveWindow = cont->window;
+    emit currentTabIndexChanged(index);
 }
 
 //------------------------------------------
@@ -1921,6 +2068,7 @@ public:
     QHash<QByteArray, QObject*> m_openedCustomObjectsForItem;
 
     int propEditorDockSeparatorPos, navDockSeparatorPos;
+
     bool wasAutoOpen;
     bool windowExistedBeforeCloseProject;
 
@@ -1929,6 +2077,8 @@ public:
 
     bool enable_slotPropertyEditorVisibilityChanged;
 
+    KexiUserFeedbackAgent userFeedback;
+
 private:
     //! @todo move to KexiProject
     KexiWindowDict windows;
