@@ -19,7 +19,7 @@
 #ifndef __KIS_PROCESSING_APPLICATOR_TEST_H
 #define __KIS_PROCESSING_APPLICATOR_TEST_H
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 class KisProcessingApplicatorTest : public QObject
 {
