@@ -19,7 +19,7 @@
 #ifndef KIS_TRANSFORM_WORKER_TEST_H
 #define KIS_TRANSFORM_WORKER_TEST_H
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 class KisTransformWorkerTest : public QObject
 {
@@ -43,6 +43,7 @@ private slots:
     void testRotation();
     void testMatrices();
     void testRotationSpecialCases();
+    void testScaleUp5times();
 
 };
 
