@@ -93,7 +93,6 @@ public:
     virtual ~KisToolTransform();
 
     virtual QWidget* createOptionWidget();
-    virtual QWidget* optionWidget();
 
     virtual void mousePressEvent(KoPointerEvent *e);
     virtual void mouseMoveEvent(KoPointerEvent *e);
@@ -315,10 +314,10 @@ private:
     bool m_boxValueChanged; // true if a boxValue has been changed directly by the user (not by click + move mouse)
     bool m_editWarpPoints;
 
-    QImage *m_origImg; // image of the pixels in selection bound rect
+    QImage m_origImg; // image of the pixels in selection bound rect
     QTransform m_transform; // transformation to apply on origImg
     QImage m_currImg; // origImg transformed using m_transform
-    QImage *m_origSelectionImg; // original selection with white used as alpha channel
+    QImage m_origSelectionImg; // original selection with white used as alpha channel
     QImage m_scaledOrigSelectionImg; // original selection to be drawn, scaled to the view
     QSizeF m_refSize; // used in paint() to check if the view has changed (need to update m_currSelectionImg)
 
