@@ -47,6 +47,7 @@
 #include <kis_filter_strategy.h>
 #include <generator/kis_generator_layer.h>
 #include <kis_adjustment_layer.h>
+#include <kis_mask.h>
 #include <kis_clone_layer.h>
 #include <kis_group_layer.h>
 #include <kis_image.h>
@@ -56,10 +57,11 @@
 #include <kis_transaction.h>
 #include <kis_selection.h>
 #include <flake/kis_shape_layer.h>
-#include <kis_shear_visitor.h>
 #include <kis_transform_visitor.h>
 #include <kis_undo_adapter.h>
 #include <kis_painter.h>
+#include <metadata/kis_meta_data_store.h>
+#include <metadata/kis_meta_data_merge_strategy_registry.h>
 
 #include "kis_config.h"
 #include "kis_cursor.h"
@@ -84,6 +86,7 @@
 #include "kis_node_commands_adapter.h"
 #include "kis_node_manager.h"
 
+
 KisLayerManager::KisLayerManager(KisView2 * view, KisDoc2 * doc)
         : m_view(view)
         , m_doc(doc)
@@ -147,7 +150,7 @@ void KisLayerManager::setup(KActionCollection * actionCollection)
     m_rasterizeLayer  = new KAction(i18n("Rasterize Layer"), this);
     actionCollection->addAction("rasterize_layer", m_rasterizeLayer);
     connect(m_rasterizeLayer, SIGNAL(triggered()), this, SLOT(rasterizeLayer()));
-    
+
     m_layerSaveAs  = new KAction(KIcon("document-save"), i18n("Save Layer as Image..."), this);
     actionCollection->addAction("save_layer_as_image", m_layerSaveAs);
     connect(m_layerSaveAs, SIGNAL(triggered()), this, SLOT(saveLayerAsImage()));
@@ -194,8 +197,6 @@ void KisLayerManager::updateGUI()
 void KisLayerManager::imageResizeToActiveLayer()
 {
     KisLayerSP layer;
-    KisUndoAdapter * undoAdapter = m_view->undoAdapter();
-
     KisImageWSP image = m_view->image();
 
     if (image && (layer = activeLayer())) {
@@ -299,8 +300,6 @@ void KisLayerManager::addLayer(KisNodeSP parent, KisNodeSP above)
         if (layer) {
             layer->setCompositeOp(COMPOSITE_OVER);
             m_commandsAdapter->addNode(layer.data(), parent.data(), above.data());
-            m_view->canvas()->update();
-            m_view->nodeManager()->activateNode(layer);
         } else {
             KMessageBox::error(m_view, i18n("Could not add layer to image."), i18n("Layer Error"));
         }
@@ -315,8 +314,6 @@ void KisLayerManager::addGroupLayer(KisNodeSP parent, KisNodeSP above)
         if (layer) {
             layer->setCompositeOp(COMPOSITE_OVER);
             m_commandsAdapter->addNode(layer.data(), parent.data(), above.data());
-            m_view->canvas()->update();
-            m_view->nodeManager()->activateNode(layer);
         } else {
             KMessageBox::error(m_view, i18n("Could not add layer to image."), i18n("Layer Error"));
         }
@@ -357,9 +354,6 @@ void KisLayerManager::addCloneLayer(KisNodeSP parent, KisNodeSP above)
 
             layer->setCompositeOp(COMPOSITE_OVER);
             m_commandsAdapter->addNode(layer.data(), parent.data(), above.data());
-            m_view->nodeManager()->activateNode(layer);
-
-            m_view->canvas()->update();
 
         } else {
             KMessageBox::error(m_view, i18n("Could not add layer to image."), i18n("Layer Error"));
@@ -392,8 +386,6 @@ void KisLayerManager::addShapeLayer(KisNodeSP parent, KisNodeSP above)
         if (layer) {
             layer->setCompositeOp(COMPOSITE_OVER);
             m_commandsAdapter->addNode(layer.data(), parent, above.data());
-            m_view->nodeManager()->activateNode(layer);
-            m_view->canvas()->update();
         } else {
             KMessageBox::error(m_view, i18n("Could not add layer to image."), i18n("Layer Error"));
         }
@@ -416,13 +408,7 @@ void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisNodeSP above)
     KisLayerSP l = activeLayer();
 
     KisPaintDeviceSP dev = l->projection();
-
-    KisSelectionSP selection;
-    if (l->selection())
-        selection = l->selection();
-    else
-        selection = image->globalSelection();
-
+    KisSelectionSP selection = l->selection();
     KisAdjustmentLayerSP adjl = addAdjustmentLayer(parent, above, QString(), 0, selection);
 
     KisDlgAdjustmentLayer dlg(adjl, adjl.data(), dev, adjl->image(), image->nextLayerName(), i18n("New Filter Layer"), m_view, "dlgadjustmentlayer");
@@ -432,7 +418,6 @@ void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisNodeSP above)
         m_commandsAdapter->undoLastCommand();
     } else {
         adjl->setName(dlg.layerName());
-        m_view->nodeManager()->activateNode(adjl);
     }
 }
 
@@ -484,12 +469,6 @@ void KisLayerManager::addGeneratorLayer(KisNodeSP parent, KisNodeSP above, const
 
     KisGeneratorLayerSP l = new KisGeneratorLayer(image, name, generator, selection);
     m_commandsAdapter->addNode(l.data(), parent, above.data());
-    m_view->nodeManager()->activateNode(l);
-    if (l->selection())
-        l->setDirty(l->selection()->selectedExactRect());
-    else
-        l->setDirty(image->bounds());
-
 }
 
 
@@ -530,8 +509,6 @@ void KisLayerManager::layerDuplicate()
     m_commandsAdapter->addNode(dup.data(), active->parent(), active.data());
     if (dup) {
         activateLayer(dup);
-        dup->setDirty();
-        m_view->canvas()->update();
     } else {
         KMessageBox::error(m_view, i18n("Could not add layer to image."), i18n("Layer Error"));
     }
@@ -593,14 +570,12 @@ void KisLayerManager::layerBack()
 void KisLayerManager::mirrorLayerX()
 {
     KisLayerSP layer = activeLayer();
-    
+    m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer X"));
+
     if (layer->inherits("KisShapeLayer")) {
-        m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer X"));
 
         KisTransformVisitor visitor(m_view->image(), -1.0, 1.0, 0.0, 0.0, 0.0, m_view->image()->width(), 0, 0, 0);
         layer->accept(visitor);
-
-        m_view->image()->undoAdapter()->endMacro();
     } else {
         KisPaintDeviceSP dev = activeDevice();
         if (!dev) return;
@@ -612,6 +587,18 @@ void KisLayerManager::mirrorLayerX()
 
         transaction.commit(m_view->image()->undoAdapter());
     }
+    // Now for the masks
+    KoProperties properties;
+    foreach(KisNodeSP mask, layer->childNodes(QStringList("KisMask"), properties)) {
+        KisPaintDeviceSP dev = qobject_cast<KisMask*>(mask.data())->selection()->getOrCreatePixelSelection();
+        if (!dev) continue;
+        KisTransaction transaction(i18n("Mirror Mask X"), dev);
+        QRect dirty = KisTransformWorker::mirrorX(dev, m_view->selection());
+        transaction.commit(m_view->image()->undoAdapter());
+        mask->setDirty(dirty);
+    }
+
+    m_view->image()->undoAdapter()->endMacro();
     m_doc->setModified(true);
     layersUpdated();
     m_view->canvas()->update();
@@ -620,14 +607,13 @@ void KisLayerManager::mirrorLayerX()
 void KisLayerManager::mirrorLayerY()
 {
     KisLayerSP layer = activeLayer();
-    
-    if (layer->inherits("KisShapeLayer")) {
-        m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer Y"));
 
+    m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer Y"));
+
+    if (layer->inherits("KisShapeLayer")) {
         KisTransformVisitor visitor(m_view->image(), 1.0, -1.0, 0.0, 0.0, 0.0, 0, m_view->image()->height(), 0, 0);
         layer->accept(visitor);
 
-        m_view->image()->undoAdapter()->endMacro();
     } else {
         KisPaintDeviceSP dev = activeDevice();
         if (!dev) return;
@@ -639,6 +625,19 @@ void KisLayerManager::mirrorLayerY()
 
         transaction.commit(m_view->image()->undoAdapter());
     }
+    // Now for the masks
+    KoProperties properties;
+    foreach(KisNodeSP mask, layer->childNodes(QStringList("KisMask"), properties)) {
+        KisPaintDeviceSP dev = qobject_cast<KisMask*>(mask.data())->selection()->getOrCreatePixelSelection();
+        if (!dev) continue;
+        KisTransaction transaction(i18n("Mirror Mask Y"), dev);
+        QRect dirty = KisTransformWorker::mirrorY(dev, m_view->selection());
+        transaction.commit(m_view->image()->undoAdapter());
+        mask->setDirty(dirty);
+    }
+
+    m_view->image()->undoAdapter()->endMacro();
+
     m_doc->setModified(true);
     layersUpdated();
     m_view->canvas()->update();
@@ -674,29 +673,7 @@ void KisLayerManager::rotateLayer(double radians)
     KisLayerSP layer = activeLayer();
     if (!layer) return;
 
-    KisUndoAdapter * undoAdapter = m_view->image()->undoAdapter();
-    undoAdapter->beginMacro(i18n("Rotate Layer"));
-
-    KisFilterStrategy *filter = KisFilterStrategyRegistry::instance()->value("Triangle");
-    QRect r;
-
-    if (KisSelectionSP selection = activeLayer()->selection())
-        r = selection->selectedExactRect();
-    else
-        r = layer->exactBounds();
-    double cx = r.x() + r.width() / 2.0;
-    double cy = r.y() + r.height() / 2.0;
-    qint32 tx = qint32(cx * cos(radians) - cy * sin(radians) - cx + 0.5);
-    qint32 ty = qint32(cy * cos(radians) + cx * sin(radians) - cy + 0.5);
-    KisTransformVisitor visitor(m_view->image(), 1.0, 1.0, 0, 0, radians, -tx, -ty, 0, filter);
-    layer->accept(visitor);
-    layer->parent()->setDirty(r);
-
-    undoAdapter->endMacro();
-
-    m_doc->setModified(true);
-    layersUpdated();
-    m_view->canvas()->update();
+    m_view->image()->rotateNode(layer, radians);
 }
 
 void KisLayerManager::shearLayer(double angleX, double angleY)
@@ -706,25 +683,7 @@ void KisLayerManager::shearLayer(double angleX, double angleY)
     KisLayerSP layer = activeLayer();
     if (!layer) return;
 
-    KisUndoAdapter * undoAdapter = m_view->image()->undoAdapter();
-    undoAdapter->beginMacro(i18n("Shear layer"));
-
-    KoProgressUpdater* updater = m_view->statusBar()->progress()->createUpdater();
-    updater->start(100, i18n("Shear layer"));
-    KoUpdaterPtr up = updater->startSubtask();
-
-    KisShearVisitor v(angleX, angleY, up);
-    v.setUndoAdapter(undoAdapter);
-    layer->accept(v);
-
-    undoAdapter->endMacro();
-
-    m_doc->setModified(true);
-    layersUpdated();
-    m_view->canvas()->update();
-
-    m_view->statusBar()->progress()->detachUpdater(updater);
-    updater->deleteLater();
+    m_view->image()->shearNode(layer, angleX, angleY);
 }
 
 void KisLayerManager::flattenImage()
@@ -760,17 +719,20 @@ void KisLayerManager::mergeLayer()
     KisLayerSP layer = activeLayer();
     if (!layer) return;
 
-    const KisMetaData::MergeStrategy* strategy = KisMetaDataMergeStrategyChooserWidget::showDialog(m_view);
-    if (!strategy) return;
+    if (!layer->prevSibling()) return;
+
+    if (layer->metaData()->isEmpty() && layer->prevSibling() && dynamic_cast<KisLayer*>(layer->prevSibling().data())->metaData()->isEmpty()) {
+        image->mergeDown(layer, KisMetaData::MergeStrategyRegistry::instance()->get("Drop"));
+    }
+    else {
+        const KisMetaData::MergeStrategy* strategy = KisMetaDataMergeStrategyChooserWidget::showDialog(m_view);
+        if (!strategy) return;
+        image->mergeDown(layer, strategy);
 
-    KisLayerSP  newLayer = image->mergeDown(layer, strategy);
-    if (newLayer) {
-        newLayer->setDirty();
-        m_view->nodeManager()->activateNode(newLayer);
     }
 
-    m_view->updateGUI();
 
+    m_view->updateGUI();
 }
 
 void KisLayerManager::flattenLayer()
@@ -795,15 +757,15 @@ void KisLayerManager::rasterizeLayer()
 
     KisLayerSP layer = activeLayer();
     if (!layer) return;
-    
+
     KisPaintLayerSP paintLayer = new KisPaintLayer(image, layer->name(), layer->opacity());
     KisPainter gc(paintLayer->paintDevice());
     QRect rc = layer->projection()->exactBounds();
     gc.bitBlt(rc.topLeft(), layer->projection(), rc);
-    
+
     m_commandsAdapter->beginMacro(i18n("Rasterize Layer"));
     m_commandsAdapter->addNode(paintLayer.data(), layer->parent().data(), layer.data());
-    
+
     int childCount = layer->childCount();
     for (int i = 0; i < childCount; i++) {
         m_commandsAdapter->moveNode(layer->firstChild(), paintLayer, paintLayer->lastChild());
