@@ -47,8 +47,8 @@
 #include <kiconloader.h>
 #include <kdebug.h>
 
-#include <QtCore/QAbstractItemModel>
-#include <QtCore/QMimeData>
+#include <QAbstractItemModel>
+#include <QMimeData>
 #include <QApplication>
 #include <QClipboard>
 #include <QMenu>
