@@ -23,15 +23,15 @@
 #include "Set.h"
 #include "Factory.h"
 
-#include <QtCore/QPointer>
-#include <QtGui/QItemDelegate>
-#include <QtGui/QStandardItemEditorCreator>
-#include <QtGui/QPainter>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QToolTip>
-#include <QtGui/QApplication>
-#include <QtGui/QHeaderView>
+#include <QPointer>
+#include <QItemDelegate>
+#include <QStandardItemEditorCreator>
+#include <QPainter>
+#include <QVBoxLayout>
+#include <QMouseEvent>
+#include <QToolTip>
+#include <QApplication>
+#include <QHeaderView>
 
 #include <KLocale>
 #include <KIconLoader>
@@ -395,7 +395,7 @@ void EditorView::changeSetInternal(Set *set, SetOptions options,
                 this, SLOT(slotPropertyChanged(KoProperty::Set&, KoProperty::Property&)));
         connect(d->set, SIGNAL(propertyReset(KoProperty::Set&, KoProperty::Property&)),
                 this, SLOT(slotPropertyReset(KoProperty::Set&, KoProperty::Property&)));
-//NEEDED?        connect(d->set, SIGNAL(aboutToBeCleared()), this, SLOT(slotSetWillBeCleared()));
+        connect(d->set, SIGNAL(aboutToBeCleared()), this, SLOT(slotSetWillBeCleared()));
         connect(d->set, SIGNAL(aboutToBeDeleted()), this, SLOT(slotSetWillBeDeleted()));
     }
 
@@ -435,6 +435,11 @@ void EditorView::changeSetInternal(Set *set, SetOptions options,
     }
 }
 
+void EditorView::slotSetWillBeCleared()
+{
+    changeSet(0, QByteArray());
+}
+
 void EditorView::slotSetWillBeDeleted()
 {
     changeSet(0, QByteArray());
