@@ -66,16 +66,16 @@
 #include <kstandarddirs.h>
 #include <kdesktopfile.h>
 
-#include <QtCore/QBuffer>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtGui/QPainter>
-#include <QtCore/QTimer>
+#include <QBuffer>
+#include <QDir>
+#include <QFileInfo>
+#include <QPainter>
+#include <QTimer>
 #include <QtDBus/QDBusConnection>
-#include <QtGui/QLayout>
-#include <QtGui/QApplication>
-#include <QtGui/QPrinter>
-#include <QtGui/QPrintDialog>
+#include <QLayout>
+#include <QApplication>
+#include <QPrinter>
+#include <QPrintDialog>
 #include <QGraphicsScene>
 #include <QGraphicsProxyWidget>
 
@@ -371,7 +371,7 @@ KoDocument::KoDocument(QWidget *parentWidget, QObject *parent, bool singleViewMo
         KConfigGroup cfgGrp(componentData().config(), "RDF");
         bool rdfEnabled = cfgGrp.readEntry("rdf_enabled", false);
         if (rdfEnabled) {
-            d->docRdf  = new KoDocumentRdf(this);
+            setDocumentRdf(new KoDocumentRdf(this));
         }
     }
 #endif
@@ -625,6 +625,22 @@ void KoDocument::setConfirmNonNativeSave(const bool exporting, const bool on)
     d->confirmNonNativeSave [ exporting ? 1 : 0] = on;
 }
 
+bool KoDocument::saveInBatchMode() const
+{
+    if (d->filterManager) {
+        return d->filterManager->getBatchMode();
+    }
+    return true;
+}
+
+void KoDocument::setSaveInBatchMode(const bool batchMode)
+{
+    if (!d->filterManager) {
+        d->filterManager = new KoFilterManager(this, d->progressUpdater);
+    }
+    d->filterManager->setBatchMode(batchMode);
+}
+
 bool KoDocument::wantExportConfirmation() const
 {
     return true;
@@ -799,7 +815,9 @@ KoDocumentInfo *KoDocument::documentInfo() const
 KoDocumentRdf *KoDocument::documentRdf() const
 {
 #ifdef SHOULD_BUILD_RDF
-    return d->docRdf;
+    if (d->docRdf && d->docRdf->model()) {
+        return d->docRdf;
+    }
 #endif
     return 0;
 }
@@ -807,10 +825,11 @@ KoDocumentRdf *KoDocument::documentRdf() const
 void KoDocument::setDocumentRdf(KoDocumentRdf *rdfDocument)
 {
     delete d->docRdf;
-#ifdef SHOULD_BUILD_RDF
-    d->docRdf = rdfDocument;
-#else
     d->docRdf = 0;
+#ifdef SHOULD_BUILD_RDF
+    if (rdfDocument->model()) {
+        d->docRdf = rdfDocument;
+    }
 #endif
 }
 
@@ -1778,7 +1797,7 @@ bool KoDocument::loadNativeFormat(const QString & file_)
         QString errorMsg;
         int errorLine;
         int errorColumn;
-        KoXmlDocument doc;
+        KoXmlDocument doc = KoXmlDocument(true);
         bool res;
         if (doc.setContent(&in, &errorMsg, &errorLine, &errorColumn)) {
             res = loadXML(doc, 0);
@@ -1879,7 +1898,7 @@ bool KoDocument::loadNativeFormatFromStoreInternal(KoStore *store)
     } else if (store->hasFile("root")) {   // Fallback to "old" file format (maindoc.xml)
         oasis = false;
 
-        KoXmlDocument doc;
+        KoXmlDocument doc = KoXmlDocument(true);
         bool ok = oldLoadAndParse(store, "root", doc);
         if (ok)
             ok = loadXML(doc, store);
@@ -1902,7 +1921,7 @@ bool KoDocument::loadNativeFormatFromStoreInternal(KoStore *store)
             d->docInfo->loadOasis(metaDoc);
         }
     } else if (!oasis && store->hasFile("documentinfo.xml")) {
-        KoXmlDocument doc;
+        KoXmlDocument doc = KoXmlDocument(true);
         if (oldLoadAndParse(store, "documentinfo.xml", doc)) {
             d->docInfo->load(doc);
         }
@@ -1947,7 +1966,7 @@ bool KoDocument::loadNativeFormatFromStoreInternal(KoStore *store)
 bool KoDocument::loadFromStore(KoStore *_store, const QString& url)
 {
     if (_store->open(url)) {
-        KoXmlDocument doc;
+        KoXmlDocument doc = KoXmlDocument(true);
         doc.setContent(_store->device());
         if (!loadXML(doc, _store)) {
             _store->close();
