@@ -33,7 +33,7 @@
 * it contains the version at compile time. See Calligra::versionString() if you need
 * the Calligra version used at runtime.
 */
-#define CALLIGRA_VERSION_STRING "2.4 Beta 5"
+#define CALLIGRA_VERSION_STRING "2.4.0"
 
 /**
  * @def CALLIGRA_VERSION_MAJOR
@@ -47,14 +47,14 @@
  * @ingroup CalligraMacros
  * @brief Minor version of Calligra, at compile time
 */
-#define CALLIGRA_VERSION_MINOR 3
+#define CALLIGRA_VERSION_MINOR 4
 
 /**
  * @def CALLIGRA_VERSION_RELEASE
  * @ingroup CalligraMacros
  * @brief Release version of Calligra, at compile time
 */
-#define CALLIGRA_VERSION_RELEASE 85
+#define CALLIGRA_VERSION_RELEASE 0
 
 /**
  * @ingroup CalligraMacros
@@ -77,14 +77,14 @@
  * @ingroup CalligraMacros
  * @brief If defined, indicates at compile time that Calligra is in beta stage
  */
-#define CALLIGRA_BETA 5
+// #define CALLIGRA_BETA 7
 
 /**
  * @def CALLIGRA_RC
  * @ingroup CalligraMacros
  * @brief If defined, indicates at compile time that Calligra is in "release candidate" stage
  */
-// #define CALLIGRA_RC 1
+// #define CALLIGRA_RC 2
 
 /**
  * @ingroup CalligraMacros
