@@ -290,12 +290,18 @@ public:
     virtual EffortCostMap plannedEffortCostPrDay(const QDate &start, const QDate &end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
     virtual EffortCostMap plannedEffortCostPrDay(const Resource *resource, const QDate &start, const QDate &end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const=0;
 
+    /// Returns the total planned effort for @p resource on this task (or subtasks)
+    virtual Duration plannedEffort( const Resource *resource, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
     /// Returns the total planned effort for this task (or subtasks) 
     virtual Duration plannedEffort( long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
     /// Returns the total planned effort for this task (or subtasks) on date
     virtual Duration plannedEffort(const QDate &, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
+    /// Returns the total planned effort for @p resource on this task (or subtasks) on date
+    virtual Duration plannedEffort( const Resource *resource, const QDate &date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
     /// Returns the planned effort up to and including date
     virtual Duration plannedEffortTo(const QDate &, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const { Q_UNUSED(id); return Duration::zeroDuration; }
+    /// Returns the planned effort for @p resource up to and including date
+    virtual Duration plannedEffortTo( const Resource *resource, const QDate &date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
     
     /// Returns the total actual effort for this task (or subtasks) 
     virtual Duration actualEffort() const { return Duration::zeroDuration; }
@@ -646,13 +652,7 @@ protected:
     ResourceRequestCollection m_requests;
 
 private:
-    void init();
-        
-#ifndef NDEBUG
-public:
-    virtual void printDebug(bool children, const QByteArray& indent);
-#endif
-
+    void init();        
 };
 
 ////////////////////////////////   Estimate   ////////////////////////////////
@@ -848,12 +848,6 @@ private:
     
     /// Calendar may be used when Type is Type_Duration
     Calendar *m_calendar;
-    
-#ifndef NDEBUG
-public:
-    void printDebug(const QByteArray& indent);
-#endif
-
 };
 
 }  //KPlato namespace
