@@ -44,6 +44,7 @@
 #include <KoOdfGraphicStyles.h>
 #include <KoOdfWorkaround.h>
 #include <KoTextDocumentLayout.h>
+#include <KoOdfNumberStyles.h>
 
 // KDChart
 #include <KDChartChart>
@@ -146,6 +147,7 @@ public:
     KDChart::CartesianCoordinatePlane *kdPlane;
     KDChart::PolarCoordinatePlane     *kdPolarPlane;
     KDChart::RadarCoordinatePlane     *kdRadarPlane;
+    KoOdfNumberStyles::NumericStyleFormat *numericStyleFormat;
 
     KDChart::BarDiagram   *kdBarDiagram;
     KDChart::LineDiagram  *kdLineDiagram;
@@ -191,14 +193,28 @@ public:
     bool isVisible;
 };
 
+class CartesianAxis : public KDChart::CartesianAxis
+{
+public:
+    CartesianAxis( KChart::Axis *_axis ) : KDChart::CartesianAxis(), axis(_axis) {}
+    virtual ~CartesianAxis() {}
+    virtual const QString customizedLabel( const QString& label ) const {
+        if (KoOdfNumberStyles::NumericStyleFormat *n = axis->numericStyleFormat())
+            return KoOdfNumberStyles::format(label, *n);
+        return label;
+    }
+private:
+    KChart::Axis *axis;
+};
 
 Axis::Private::Private( Axis *axis, AxisDimension dim )
     : q( axis )
     , dimension( dim )
-    , kdAxis( new KDChart::CartesianAxis )
+    , kdAxis( new CartesianAxis( axis ) )
     , kdPlane( 0 )
     , kdPolarPlane( 0 )
     , kdRadarPlane( 0 )
+    , numericStyleFormat( 0 )
 {
     centerDataPoints = false;
 
@@ -240,6 +256,8 @@ Axis::Private::~Private()
 {
     Q_ASSERT( plotArea );
 
+    delete numericStyleFormat;
+
     delete kdBarDiagram;
     delete kdAreaDiagram;
     delete kdCircleDiagram;
@@ -259,7 +277,7 @@ Axis::Private::~Private()
 
 void Axis::Private::registerDiagram( KDChart::AbstractDiagram *diagram )
 {
-    KDChartModel *model = new KDChartModel;
+    KDChartModel *model = new KDChartModel( plotArea );
     diagram->setModel( model );
 
     QObject::connect( plotArea->proxyModel(), SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
@@ -1089,6 +1107,38 @@ bool Axis::showOuterMajorTicks() const
     return d->showOuterMajorTicks;
 }
 
+void Axis::setShowInnerMinorTicks( bool showTicks )
+{
+    d->showInnerMinorTicks = showTicks;
+    KDChart::RulerAttributes attr = kdAxis()->rulerAttributes();
+    attr.setShowMinorTickMarks(d->showInnerMinorTicks || d->showOuterMinorTicks);
+    kdAxis()->setRulerAttributes( attr );
+}
+
+void Axis::setShowOuterMinorTicks( bool showTicks )
+{
+    d->showOuterMinorTicks = showTicks;
+    KDChart::RulerAttributes attr = kdAxis()->rulerAttributes();
+    attr.setShowMinorTickMarks(d->showInnerMinorTicks || d->showOuterMinorTicks);
+    kdAxis()->setRulerAttributes( attr );
+}
+
+void Axis::setShowInnerMajorTicks( bool showTicks )
+{
+    d->showInnerMajorTicks = showTicks;
+    KDChart::RulerAttributes attr = kdAxis()->rulerAttributes();
+    attr.setShowMajorTickMarks(d->showInnerMajorTicks || d->showOuterMajorTicks);
+    kdAxis()->setRulerAttributes( attr );
+}
+
+void Axis::setShowOuterMajorTicks( bool showTicks )
+{
+    d->showOuterMajorTicks = showTicks;
+    KDChart::RulerAttributes attr = kdAxis()->rulerAttributes();
+    attr.setShowMajorTickMarks(d->showInnerMajorTicks || d->showOuterMajorTicks);
+    kdAxis()->setRulerAttributes( attr );
+}
+
 void Axis::setScalingLogarithmic( bool logarithmicScaling )
 {
     d->logarithmicScaling = logarithmicScaling;
@@ -1176,6 +1226,7 @@ Qt::Orientation Axis::orientation()
 bool Axis::loadOdf( const KoXmlElement &axisElement, KoShapeLoadingContext &context )
 {
     KoStyleStack &styleStack = context.odfLoadingContext().styleStack();
+    KoOdfStylesReader &stylesReader = context.odfLoadingContext().stylesReader();
     OdfLoadingHelper *helper = (OdfLoadingHelper*)context.sharedData( OdfLoadingHelperId );
     bool reverseAxis = false;
 
@@ -1197,6 +1248,17 @@ bool Axis::loadOdf( const KoXmlElement &axisElement, KoShapeLoadingContext &cont
     setMinorInterval( 0.0 );
 
     if ( !axisElement.isNull() ) {
+
+        QString styleName = axisElement.attributeNS(KoXmlNS::chart, "style-name", QString());
+        const KoXmlElement *stylElement = stylesReader.findStyle(styleName, "chart");
+        if (stylElement) {
+            const QString dataStyleName = stylElement->attributeNS(KoXmlNS::style, "data-style-name", QString());
+            if (!dataStyleName.isEmpty() && stylesReader.dataFormats().contains(dataStyleName)) {
+                delete d->numericStyleFormat;
+                d->numericStyleFormat = new KoOdfNumberStyles::NumericStyleFormat(stylesReader.dataFormats()[dataStyleName].first);
+            }
+        }
+
         KoXmlElement n;
         forEachElement ( n, axisElement ) {
             if ( n.namespaceURI() != KoXmlNS::chart )
@@ -1315,6 +1377,18 @@ bool Axis::loadOdf( const KoXmlElement &axisElement, KoShapeLoadingContext &cont
             setMajorInterval( KoUnit::parseValue( styleStack.property( KoXmlNS::chart, "interval-major" ) ) );
         if ( styleStack.hasProperty( KoXmlNS::chart, "interval-minor-divisor" ) )
             setMinorIntervalDivisor( KoUnit::parseValue( styleStack.property( KoXmlNS::chart, "interval-minor-divisor" ) ) );
+        else if ( styleStack.hasProperty( KoXmlNS::chart, "interval-minor" ) )
+            setMinorInterval( KoUnit::parseValue( styleStack.property( KoXmlNS::chart, "interval-minor" ) ) );
+
+        if ( styleStack.hasProperty( KoXmlNS::chart, "tick-marks-minor-inner" ) )
+            setShowInnerMinorTicks(styleStack.property( KoXmlNS::chart, "tick-marks-minor-inner" ) == "true");
+        if ( styleStack.hasProperty( KoXmlNS::chart, "tick-marks-minor-outer" ) )
+            setShowOuterMinorTicks(styleStack.property( KoXmlNS::chart, "tick-marks-minor-outer" ) == "true");
+        if ( styleStack.hasProperty( KoXmlNS::chart, "tick-marks-major-inner" ) )
+            setShowInnerMajorTicks(styleStack.property( KoXmlNS::chart, "tick-marks-major-inner" ) == "true");
+        if ( styleStack.hasProperty( KoXmlNS::chart, "tick-marks-major-outer" ) )
+            setShowOuterMajorTicks(styleStack.property( KoXmlNS::chart, "tick-marks-major-outer" ) == "true");
+
         if ( styleStack.hasProperty( KoXmlNS::chart, "display-label" ) )
             setShowLabels( styleStack.property( KoXmlNS::chart, "display-label" ) != "false" );
         if ( styleStack.hasProperty( KoXmlNS::chart, "visible" ) )
@@ -1339,6 +1413,7 @@ bool Axis::loadOdf( const KoXmlElement &axisElement, KoShapeLoadingContext &cont
             else
                 d->kdPlane->setHorizontalRange( qMakePair( minimum, maximum ) );
         }
+
         styleStack.setTypeProperties( "text" );
         if ( styleStack.hasProperty( KoXmlNS::fo, "font-size" ) )
         {
@@ -1362,6 +1437,19 @@ bool Axis::loadOdf( const KoXmlElement &axisElement, KoShapeLoadingContext &cont
                 kdAxis()->setTextAttributes( tatt );
             }
         }
+        if ( styleStack.hasProperty( KoXmlNS::fo, "font-color" ) )
+        {
+            QString fontColorString =  styleStack.property( KoXmlNS::fo, "font-color" );
+            QColor color(fontColorString);
+            if ( color.isValid() )
+            {
+                KDChart::TextAttributes tatt =  kdAxis()->textAttributes();
+                QPen pen = tatt.pen();
+                pen.setColor(color);
+                tatt.setPen(pen);
+                kdAxis()->setTextAttributes( tatt );
+            }
+        }
     } else {
         setShowLabels( KoOdfWorkaround::fixMissingStyle_DisplayLabel( axisElement, context ) );
     }
@@ -1931,4 +2019,15 @@ void Axis::setVisible( bool visible )
         deregisterKdAxis( d->kdAxis );
 }
 
+KoOdfNumberStyles::NumericStyleFormat *Axis::numericStyleFormat() const
+{
+    return d->numericStyleFormat;
+}
+
+void Axis::SetNumericStyleFormat(KoOdfNumberStyles::NumericStyleFormat *numericStyleFormat) const
+{
+    delete d->numericStyleFormat;
+    d->numericStyleFormat = numericStyleFormat;
+}
+
 #include "Axis.moc"
